<html>
   <head>
    <meta content="text/html;charset=utf-8" http-equiv="Content-Type">
    <meta content="utf-8" http-equiv="encoding">
    <title>ewuuu</title>
    <link rel="stylesheet" type="text/css" href="/static/style.css" />
    <script src="/static/jquery.js"></script>
    <script src="/static/handlebars.js"></script>
    <script src="/static/underscore.js"></script>
  </head>
<body>
  <form action="/upload/" method="POST">
    <textarea name="bibtex" style="width:100%; height: 90%"></textarea>
    <input type="submit" value="Add your bibtex" style="width: 100%; font-size: 25pt; height: 25pt;"></input>
  </form>
</body>
</html>
